@@ -18,10 +18,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-
-#include <gconf/gconf-backend.h>
-#include <gconf/gconf-internals.h>
-#include <gconf/gconf.h>
+#include "config.h"
+#include "gconf/gconf-backend.h"
+#include "gconf/gconf-internals.h"
+#include "gconf/gconf.h"
 
 #include "xml-cache.h"
 
@@ -797,7 +797,7 @@ blow_away_locks (const char *address)
 
 /* Initializer */
 
-#ifndef G_OS_WIN32
+#ifndef G_PLATFORM_WIN32
 /* If we use G_MODULE_EXPORT, *only* thusly marked functions will be
  * exported, and xml-test uses other ones, too.
  */
@@ -814,7 +814,7 @@ g_module_check_init (GModule *module)
   return NULL;
 }
 
-#ifndef G_OS_WIN32
+#ifndef G_PLATFORM_WIN32
 G_MODULE_EXPORT
 #endif
 GConfBackendVTable* 
@@ -854,7 +854,7 @@ xs_new       (const gchar* root_dir, guint dir_mode, guint file_mode, GConfLock*
 
   xs->cache = cache_get(xs->root_dir, dir_mode, file_mode);
 
-  xs->timeout_id = g_timeout_add(1000*60*5, /* 1 sec * 60 s/min * 5 min */
+  xs->timeout_id = g_timeout_add_seconds(60*5, /* 1 sec * 60 s/min * 5 min */
                                  cleanup_timeout,
                                  xs);
 
